@@ -4,6 +4,7 @@ from .functions import *
 commands = [
     Command(("水平翻转", "左翻", "右翻"), flip_horizontal),
     Command(("竖直翻转", "上翻", "下翻"), flip_vertical),
+    Command(("灰度图", "黑白"), grey),
     Command(("旋转",), rotate),
     Command(("缩放",), resize),
     Command(("裁剪",), crop),
@@ -16,6 +17,7 @@ commands = [
     Command(("颜色滤镜",), color_mask),
     Command(("纯色图",), color_image),
     Command(("gif倒放", "倒放"), gif_reverse),
+    Command(("gif正放倒放", "正放倒放"), gif_obverse_reverse),
     Command(("gif分解",), gif_split),
     Command(("四宫格",), four_grid),
     Command(("九宫格",), nine_grid),
